#
# spec file for package imake
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           imake
Version:        1.0.9
Release:        1.3
Summary:        C preprocessor interface to the make utility
License:        MIT
Group:          Development/Tools/Building
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/util/%{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto)
# For Imake.tmpl, Just in case packagers don't know it's in this package.
Requires:       xorg-cf-files
# This was part of the xorg-x11-util-devel package up to version 7.6
Conflicts:      xorg-x11-util-devel <= 7.6

%description
Imake is used to generate Makefiles from a template, a set of cpp macro
functions, and a per-directory input file called an Imakefile.

The X Window System used imake extensively up through the X11R6.9
release, for both full builds within the source tree and external
software. X has since moved to GNU autoconf and automake for its build
system in X11R7.0 and later releases, but still maintains imake for
building existing external software programs that have not yet
converted.

%prep
%setup -q

%build
%configure --with-config-dir=%{_datadir}/X11/config
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/ccmakedep
%{_bindir}/cleanlinks
%{_bindir}/imake
%{_bindir}/makeg
%{_bindir}/mergelib
%{_bindir}/mkdirhier
%{_bindir}/mkhtmlindex
%{_bindir}/revpath
%{_bindir}/xmkmf
%{_mandir}/man1/ccmakedep.1%{?ext_man}
%{_mandir}/man1/cleanlinks.1%{?ext_man}
%{_mandir}/man1/imake.1%{?ext_man}
%{_mandir}/man1/makeg.1%{?ext_man}
%{_mandir}/man1/mergelib.1%{?ext_man}
%{_mandir}/man1/mkdirhier.1%{?ext_man}
%{_mandir}/man1/mkhtmlindex.1%{?ext_man}
%{_mandir}/man1/revpath.1%{?ext_man}
%{_mandir}/man1/xmkmf.1%{?ext_man}

%changelog
* Thu Oct 20 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.9
  * gitlab CI: add a basic build test
  * Fix spelling/wording issues
  * Use AC_CONFIG_FILES to replace the deprecated AC_OUTPUT with parameters
  * Fix -Wsign-compare warnings
  * Fix -Wshadow warnings
  * Make Emalloc() argument a size_t to match malloc()
  * Simplify HAVE_MKSTEMP block
  * unifdef SIGNALRETURNSINT
  * Add .git-blame-ignore-revs to hide whitespace commits from git blame
  * autogen.sh: use quoted string variables
  * autogen.sh: use exec instead of waiting for configure to finish
* Sun May 16 2021 Dirk Müller <dmueller@suse.com>
- modernize spec-file (move license to licensedir)
* Fri Mar 22 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.8
  * autogen: add default patch prefix
  * autogen.sh: Honor NOCONFIGURE=1
  * configure: Drop AM_MAINTAINER_MODE
  * Update configure.ac bug URL for gitlab migration
  * Use SEEK_* names instead of raw numbers for fseek whence argument
  * imake support for lcc compiler
  * README: reword status section
  * Update README for gitlab migration
* Thu May 22 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.7:
  This release fixes generation of the ccmakedep, mergelib and
  xmkmf scripts when using GNU cpp >= 4.8.
* Wed Aug 14 2013 zaitor@opensuse.org
- Update to version 1.0.6:
  + Avoid use of low-level troff markup that can't be lifted
    structurally.
  + config: replace deprecated AM_CONFIG_HEADER with
    AC_CONFIG_HEADERS.
  + Let configure pick cpp path on Solaris, instead of hardcoding
    in imakemdep.h.
  + Ensure inFile is always closed on error in cppit().
  + Avoid closing inFile twice in CheckImakefileC if LogFatal
    returns.
* Sat Jun 30 2012 i@marguerite.su
- add Requires: xorg-cf-files.
  * or every package needs imake will come with a
    "Imake.tmpl: no such file or directory" error.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split imake from xorg-x11-util-devel. Initial version: 1.0.5.
